@@ -30,6 +30,7 @@ import subprocess
 import socket
 import time
 import glob
+import stat
 
 import sabnzbd
 from sabnzbd.decorators import synchronized
@@ -301,7 +302,10 @@ def real_path(loc, path):
         if not sabnzbd.WIN32 and path.startswith('~/'):
             path = path.replace('~', sabnzbd.DIR_HOME, 1)
         if sabnzbd.WIN32:
-            if path[0] not in '/\\' and not (len(path) > 1 and path[0].isalpha() and path[1] == ':'):
+            if path[0].isalpha() and len(path) > 1 and path[1] == ':':
+                if len(path) == 2 or path[2] not in '\\/':
+                    path = path.replace(':', ':\\', 1)
+            else:
                 path = os.path.join(loc, path)
         elif path[0] != '/':
             path = os.path.join(loc, path)
@@ -1166,3 +1170,10 @@ def remove_all(path, pattern='*', keep_folder=False, recursive=False):
             except:
                 logging.info('Cannot remove folder %s', path)
 
+
+def is_writable(path):
+    """ Return True is file is writable (also when non-existent) """
+    if os.path.isfile(path):
+        return bool(os.stat(path).st_mode & stat.S_IWUSR)
+    else:
+        return True
