@@ -28,7 +28,8 @@ from time import time
 import binascii
 
 import sabnzbd
-from sabnzbd.encoding import TRANS, UNTRANS, unicode2local, name_fixer, reliable_unpack_names, unicoder, latin1
+from sabnzbd.encoding import TRANS, UNTRANS, unicode2local, name_fixer, \
+     reliable_unpack_names, unicoder, latin1, platform_encode
 from sabnzbd.utils.rarfile import RarFile, is_rarfile
 from sabnzbd.misc import format_time_string, find_on_path, make_script_path
 from sabnzbd.tvsort import SeriesSorter
@@ -588,8 +589,16 @@ def rar_extract_core(rarfile, numrars, one_folder, nzo, setname, extraction_path
             nzo.set_unpack_info('Unpack', unicoder(msg), set=setname)
             fail = 1
 
-        elif line.startswith('Encrypted file:  CRC failed'):
-            filename = TRANS(line[31:-23].strip())
+        elif 'ncrypted file' in line and 'CRC failed' in line:
+            # unrar 4.x syntax
+            m = re.search('encrypted file (.+)\. Corrupt file', line)
+            if not m:
+                # unrar 3.x syntax
+                m = re.search('Encrypted file:  CRC failed in (.+) \(password', line)
+            if m:
+                filename = TRANS(m.group(1)).strip()
+            else:
+                filename = '???'
             nzo.fail_msg = T('Unpacking failed, archive requires a password')
             msg = ('[%s][%s] '+Ta('Unpacking failed, archive requires a password')) % (setname, latin1(filename))
             nzo.set_unpack_info('Unpack', unicoder(msg), set=setname)
@@ -1330,7 +1339,7 @@ def sfv_check(sfv_path):
             x = line.rfind(' ')
             filename = line[:x].strip()
             checksum = line[x:].strip()
-            path = os.path.join(root, filename)
+            path = os.path.join(root, platform_encode(filename))
             if os.path.exists(path):
                 if crc_check(path, checksum):
                     logging.debug('File %s passed SFV check', path)
